@@ -6,8 +6,6 @@ use virtual_node::VirtualNode;
 
 /// Test that we generate the right Vec<Patch> for some start and end virtual dom.
 pub struct DiffTestCase<'a> {
-    // ex: "Patching root level nodes works"
-    pub description: &'static str,
     // ex: html! { <div> </div> }
     pub old: VirtualNode,
     // ex: html! { <strong> </strong> }
@@ -21,6 +19,6 @@ impl<'a> DiffTestCase<'a> {
         // ex: vec![Patch::Replace(0, &html! { <strong></strong> })],
         let patches = diff(&self.old, &self.new);
 
-        assert_eq!(patches, self.expected, "{}", self.description);
+        assert_eq!(patches, self.expected);
     }
 }
