@@ -8,36 +8,35 @@
 
 extern crate wasm_bindgen;
 
+pub use wasm_bindgen::JsCast;
 // Used so that `html!` calls work when people depend on this crate since `html!` needs
 // access to `Closure` when creating event handlers.
 pub use wasm_bindgen::prelude::Closure;
-pub use wasm_bindgen::JsCast;
-
-pub extern crate web_sys;
-pub use web_sys::*;
 
+pub use html_macro::html;
 pub use virtual_node::*;
 
-mod diff;
 pub use crate::diff::*;
-
-mod patch;
 pub use crate::patch::*;
 
-// FIXME: Remove this and have users depend on html-macro directly.
-//  That way we don't need to re-release this crate whenever we update html-macro.
-pub use html_macro::html;
+pub use self::pdom::PercyDom;
 
-mod dom_updater;
-pub use self::dom_updater::DomUpdater;
+mod diff;
+mod patch;
+mod pdom;
 
 /// Exports structs and macros that you'll almost always want access to in a virtual-dom
 /// powered application
 pub mod prelude {
-    pub use crate::dom_updater::DomUpdater;
-    pub use crate::VirtualNode;
-    pub use html_macro::html;
+    // TODO: look through this prelude and remove anything that isn't necessary.
+
     pub use std::vec::IntoIter;
-    pub use virtual_node::{event::*, wrap_closure, EventAttribFn, IterableNodes, View};
+
     pub use wasm_bindgen::prelude::Closure;
+
+    pub use html_macro::html;
+    pub use virtual_node::{event::*, wrap_closure, EventAttribFn, IterableNodes, View};
+
+    pub use crate::pdom::PercyDom;
+    pub use crate::VirtualNode;
 }
