@@ -1,12 +1,17 @@
 //! Our Patch enum is intentionally kept in it's own file for easy inclusion into
 //! The Percy Book.
 
-use crate::{AttributeValue, VText, VirtualNode};
 use std::collections::HashMap;
 
-mod apply_patches;
 pub use apply_patches::patch;
 
+use crate::event::{EventHandler, EventName};
+use crate::{AttributeValue, VText, VirtualNode};
+
+mod apply_patches;
+
+type NodeIdx = u32;
+
 /// A Patch encodes an operation that modifies a real DOM element.
 ///
 /// To update the real DOM that a user sees you'll want to first diff your
@@ -40,15 +45,25 @@ pub use apply_patches::patch;
 /// ```
 ///
 /// The patching process is tested in a real browser in crates/percy-dom/tests/diff_patch.rs
-#[derive(Debug, PartialEq)]
+#[derive(Debug)]
+#[cfg_attr(any(test, feature = "__test-utils"), derive(PartialEq))]
 pub enum Patch<'a> {
     /// Append a vector of child nodes to a parent node id.
-    AppendChildren(NodeIdx, Vec<&'a VirtualNode>),
+    #[allow(missing_docs)]
+    AppendChildren {
+        old_idx: NodeIdx,
+        new_nodes: Vec<(NodeIdx, &'a VirtualNode)>,
+    },
     /// For a `node_i32`, remove all children besides the first `len`
     TruncateChildren(NodeIdx, usize),
     /// Replace a node with another node. This typically happens when a node's tag changes.
     /// ex: <div> becomes <span>
-    Replace(NodeIdx, &'a VirtualNode),
+    #[allow(missing_docs)]
+    Replace {
+        old_idx: NodeIdx,
+        new_idx: NodeIdx,
+        new_node: &'a VirtualNode,
+    },
     /// The value attribute of a textarea or input element has not changed, but we will still patch
     /// it anyway in case something was typed into the field.
     ValueAttributeUnchanged(NodeIdx, &'a AttributeValue),
@@ -60,6 +75,20 @@ pub enum Patch<'a> {
     ChangeText(NodeIdx, &'a VText),
     /// Patches that apply to [`SpecialAttributes`].
     SpecialAttribute(PatchSpecialAttribute<'a>),
+    /// Remove the `__events_id__` property from the DOM node.
+    /// This happens when the node no longer has any events.
+    RemoveEventsId(NodeIdx),
+    /// Set the `__events_id__` property on the DOM node.
+    SetEventsId(NodeIdx),
+    /// Insert events in the EventsByNodeIdx.
+    /// If it is a non-delegated event the event will also get added to the DOM node.
+    AddEvents(NodeIdx, HashMap<&'a EventName, &'a EventHandler>),
+    /// Remove events from the EventsByNodeIdx.
+    /// If it is a non-delegated event the event will also get removed from the DOM node.
+    RemoveEvents(NodeIdx, Vec<(&'a EventName, &'a EventHandler)>),
+    /// Delete all events in the EventsByNodeIdx for the given index, since the node has been
+    /// removed from the DOM.
+    RemoveAllManagedEventsWithNodeIdx(NodeIdx),
 }
 
 /// Patches that apply to [`SpecialAttributes`].
@@ -73,18 +102,15 @@ pub enum PatchSpecialAttribute<'a> {
     RemoveDangerousInnerHtml(NodeIdx),
 }
 
-// TODO: u32 instead of usize
-type NodeIdx = usize;
-
 impl<'a> Patch<'a> {
     /// Every Patch is meant to be applied to a specific node within the DOM. Get the
     /// index of the DOM node that this patch should apply to. DOM nodes are indexed
     /// depth first with the root node in the tree having index 0.
-    pub fn node_idx(&self) -> NodeIdx {
+    pub(crate) fn old_node_idx(&self) -> NodeIdx {
         match self {
-            Patch::AppendChildren(node_idx, _) => *node_idx,
+            Patch::AppendChildren { old_idx, .. } => *old_idx,
             Patch::TruncateChildren(node_idx, _) => *node_idx,
-            Patch::Replace(node_idx, _) => *node_idx,
+            Patch::Replace { old_idx, .. } => *old_idx,
             Patch::AddAttributes(node_idx, _) => *node_idx,
             Patch::RemoveAttributes(node_idx, _) => *node_idx,
             Patch::ChangeText(node_idx, _) => *node_idx,
@@ -94,6 +120,16 @@ impl<'a> Patch<'a> {
                 PatchSpecialAttribute::SetDangerousInnerHtml(node_idx, _) => *node_idx,
                 PatchSpecialAttribute::RemoveDangerousInnerHtml(node_idx) => *node_idx,
             },
+            Patch::RemoveEventsId(node_idx) => *node_idx,
+            Patch::SetEventsId(node_idx) => *node_idx,
+            Patch::RemoveEvents(node_idx, _) => *node_idx,
+            Patch::AddEvents(node_idx, _) => *node_idx,
+            Patch::RemoveAllManagedEventsWithNodeIdx(node_idx) => {
+                // TODO: We don't actually need the old node for this particular patch..
+                //  so we should stop making use of this. Perhaps use `unreachable!()` and fix
+                //  the places where we use this to stop using it.
+                *node_idx
+            }
         }
     }
 }
