@@ -22,8 +22,10 @@ impl<'a> DiffPatchTest<'a> {
     pub fn test(&mut self) {
         console_error_panic_hook::set_once();
 
+        let mut events = EventsByNodeIdx::new();
+
         // Create a DOM node of the virtual root node
-        let root_node: Node = self.old.create_dom_node().node;
+        let root_node: Node = self.old.create_dom_node(0, &mut events);
 
         // Clone since percy_dom::patch takes ownership of the root node.
         let patched_root_node: Node = root_node.clone();
@@ -32,7 +34,7 @@ impl<'a> DiffPatchTest<'a> {
         let patches = percy_dom::diff(&self.old, &self.new);
 
         // Patch our root node. It should now look like `self.new`
-        percy_dom::patch(root_node, &patches).unwrap();
+        percy_dom::patch(root_node, &self.new, &mut events, &patches).unwrap();
 
         // Determine the expected outer HTML
         let expected_outer_html = match self.override_expected {
